Stan Math Library: stan/math/prim/arr/fun/sum.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
sum.hpp File Reference
`#include <cstddef>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::sum (const std::vector< T > &xs)
| Return the sum of the values in the specified standard vector. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.